==================
locationsharinglib
==================

A library to retrieve coordinates from an google account that has been shared locations of other accounts. 


* Documentation: https://locationsharinglib.readthedocs.org/en/latest

Features
--------

* TODO
